#
# spec file for package openbsc
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %nil

Name:           openbsc
Version:        1.3.2
Release:        bp153.1.19
Summary:        Base station controller for a GSM stack
License:        AGPL-3.0-or-later AND GPL-3.0-or-later AND GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://osmocom.org/projects/openbsc/wiki/OpenBSC
Source:         openbsc-%version.tar.xz
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libdbi-drivers-dbd-sqlite3
BuildRequires:  libpcap-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  python3
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(dbi)
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libcrypto) >= 0.9.5
BuildRequires:  pkgconfig(libosmo-netif) >= 0.4.0
BuildRequires:  pkgconfig(libosmoabis) >= 0.6.0
BuildRequires:  pkgconfig(libosmocore) >= 1.0.1
BuildRequires:  pkgconfig(libosmoctrl) >= 1.0.1
BuildRequires:  pkgconfig(libosmogb) >= 1.0.1
BuildRequires:  pkgconfig(libosmogsm) >= 1.0.1
BuildRequires:  pkgconfig(libosmovty) >= 1.0.1
BuildRequires:  pkgconfig(libsmpp34) >= 1.13.0
BuildRequires:  pkgconfig(sqlite3)
Requires:       libdbi-drivers-dbd-sqlite3
Provides:       osmocom-bsc-sccplite
Provides:       osmocom-nitb

%description
An implementation of the minimal subset of the major backend
components of a GSM network, such as BSC, MSC, HLR, EIR. Using a
commercial GSM BTS and attaching it to a Linux system running the
OpenBSC software allows you to run your own GSM "network in a box".

OsmoBSC can run in one of two modes:
* as OsmoBSC, exposing an A interface towards an external MSC, or
* as OsmoNITB (Network In The Box), which implements a minimal subset
  of the BSC, MSC. SMSC and HLR

%package bs11-utils
Summary:        Command line utilities for Siemens BS-11 BTS
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
Conflicts:      osmo-bsc-bs11-utils

%description bs11-utils
There is a tool in this package for configuring the Siemens BS-11 BTS.
Additionally, it contains one tool for making use of an ISDN-card and the
public telephone network as frequency standard for the E1 line.

%package bsc-sccplite
Summary:        GSM Base Station Controller
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
Recommends:     bsc-sccplite

%description bsc-sccplite
This is the BSC-only version of OpenBSC. It requires a Mobile Switching Center
(MSC) to operate.

You might rather prefer to use openbsc (osmo-nitb) which is considered a
"GSM Network-in-a-Box" and does not depend on a MSC.

%prep
%setup -q

%build
pushd openbsc/
echo "%version" >.tarball-version
autoreconf -fi
%configure --disable-static --includedir="%_includedir/%name" \
	--docdir="%_docdir/%name" --with-systemdsystemunitdir="%_unitdir" \
	--enable-smpp
make %{?_smp_mflags}
popd

%install
pushd openbsc/
%make_install
popd
find %buildroot -type f -name "*.la" -delete -print
install -d %buildroot/%_localstatedir/lib/osmocom

install -d %buildroot/%_sbindir
ln -s %_sbindir/service %buildroot/%_sbindir/rcosmo-nitb
ln -s %_sbindir/service %buildroot/%_sbindir/rcosmo-bsc-mgcp

# FIXME: remove uneeded files
rm -rf %buildroot/%_includedir/%name

%check
pushd openbsc/
make %{?_smp_mflags} check || find . -name testsuite.log -exec cat {} +
popd

%pre
%service_add_pre osmo-nitb.service

%post
%service_add_post osmo-nitb.service

%preun
%service_del_preun osmo-nitb.service

%postun
%service_del_postun osmo-nitb.service

%pre bsc-sccplite
%service_add_pre osmo-bsc-mgcp.service

%post bsc-sccplite
%service_add_post osmo-bsc-mgcp.service

%preun bsc-sccplite
%service_del_preun osmo-bsc-mgcp.service

%postun bsc-sccplite
%service_del_postun osmo-bsc-mgcp.service

%files
%license openbsc/COPYING
%doc openbsc/AUTHORS openbsc/README
%_docdir/openbsc
%_bindir/osmo-nitb
%dir %_sysconfdir/osmocom
%config %_sysconfdir/osmocom/osmo-nitb.cfg
%_unitdir/osmo-nitb.service
%_sbindir/rcosmo-nitb
%dir %_localstatedir/lib/osmocom

%files bs11-utils
%_bindir/bs11_config
%_bindir/isdnsync

%files bsc-sccplite
%_bindir/osmo-bsc_mgcp
%dir %_sysconfdir/osmocom
%config %_sysconfdir/osmocom/osmo-bsc-mgcp.cfg
%_unitdir/osmo-bsc-mgcp.service
%_sbindir/rcosmo-bsc-mgcp

%changelog
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.3.2
  * osmoappdesc.py, tests, ipa.py: switch to python 3
* Wed Aug 14 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.3.1
  * Don't deliver alert notifications to an ESME that is not yet bound.
  * Write configuration correctly from vty (alert notifications)
  * nat: Fix crash (double-free) in forward_sccp_to_msc
* Sat Jul 27 2019 Martin Hauke <mardnh@gmx.de>
- Disable LTO for now since it breaks compilation of the tests
  See: https://osmocom.org/issues/4112
* Wed Mar  6 2019 Martin Hauke <mardnh@gmx.de>
- Add conflicts to osmo-bsc-bs11-utils
* Thu Jan 31 2019 mardnh@gmx.de
- Update to version 1.2.0
  * Remove meas_* and ipaccess utils
  * Fix various use-after-free issues and memory leaks
  * Replace '.' in counter names with ':'
  * Extend the output of various VTY-commands
  * libmsc: add support for both comp128v2 and comp128v3
  * Full changelogs since 1.0.0:
    http://git.osmocom.org/openbsc/plain/debian/changelog?h=1.2.0
    http://git.osmocom.org/openbsc/plain/debian/changelog?h=1.1.0
- Remove patches:
  * build-fixes.diff
* Sat Mar 17 2018 mardnh@gmx.de
- Always run build-checks
- Remove unnecessary BuildRequires
- Show testsuite.log when tests are failing
- Create subpackages for
  * abisip-find
  * ipaccess-utils
  * bs11-utils
  * meas-utils
  * bsc-nat
  * bsc-sccplite
* Wed Dec 27 2017 mardnh@gmx.de
- Build with --enable-nat, --enable-osmo-bsc, --enable-smpp
- Specfile cleanup
* Wed Dec 27 2017 mardnh@gmx.de
- Update to new upstream release 1.0.0
  * No changelog was provided
* Sun Apr 30 2017 jengelh@inai.de
- Ship version 0.15.0.750 for build.opensuse.org
